@@ -35,14 +35,14 @@ constexpr int HEADER_SIZE = 16384;
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief constructor
-//! \param imagefile_impl imagefile_impl object
+//! \brief Constructor
+//! \param impl imagefile_impl object
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-reader_impl_aes::reader_impl_aes (const imagefile_impl& imagefile_impl)
-  : size_ (imagefile_impl.get_size ()),
-    cipher_ (imagefile_impl.get_encryption_key ())
+reader_impl_aes::reader_impl_aes (const imagefile_impl& impl)
+  : size_ (impl.get_size ()),
+    cipher_ (impl.get_encryption_key ())
 {
-  auto f = mobius::io::new_file_by_url (imagefile_impl.get_url ());
+  auto f = impl.get_file ();
   stream_ = f.new_reader ();
   stream_.seek (HEADER_SIZE);
 }
@@ -71,7 +71,10 @@ reader_impl_aes::seek (offset_type offset, whence_type w)
     throw std::invalid_argument (MOBIUS_EXCEPTION_MSG ("Invalid whence_type"));
 
   // update current pos, if possible
-  if (abs_offset >= 0 && size_type (abs_offset) < size_)
+  if (abs_offset < 0)
+    throw std::invalid_argument (MOBIUS_EXCEPTION_MSG ("invalid offset"));
+  
+  else if (size_type (abs_offset) <= size_)  
     pos_ = abs_offset;
 }
 
